/**
 * @file
 * @brief Constants and macros for use with CMSIS RTOS2.
 */
#ifndef STA_RTOS2_DEFS_HPP
#define STA_RTOS2_DEFS_HPP

/**
 * @defgroup rtos2 RTOS2
 * @brief CMSIS RTOS2 library.
 */

/**
 * @defgroup rtos2API API
 * @ingroup rtos2
 * @brief Public interface.
 */

/**
 * @defgroup rtos2BuildConfig Build config
 * @ingroup rtos2
 * @brief Build configuration options.
 */


/**
 * @ingroup rtos2API
 * @{
 */

// See limits defined in cmsis_os2.c

/**
 * @brief Number of usable bits in task notification flags.
 */
#define STA_RTOS2_MAX_BITS_TASK_NOTIFY      31U
/**
 * @brief Number of usable bits in event group flags.
 */
#define STA_RTOS2_MAX_BITS_EVENT_GROUPS     24U
/**
 * @brief Mask for valid task notification flag bits.
 */
#define STA_RTOS2_THREAD_FLAGS_VALID_BITS   ((1UL << STA_RTOS2_MAX_BITS_TASK_NOTIFY) - 1U)
/**
 * @brief Mask for valid event group flag bits.
 */
#define STA_RTOS2_EVENT_FLAGS_VALID_BITS	((1UL << STA_RTOS2_MAX_BITS_EVENT_GROUPS) - 1U)


/** @} */

#endif // STA_RTOS2_DEFS_HPP
